🔸UAVSAR — PolSARtools 0.8 documentation

Skip to main content
`Ctrl`+`K`

# 🔸UAVSAR

## GRD (`uavsar_grd`)

The uavsar_grd function extracts matrix elements (C3 or T3) from the given UAVSAR .ann file and saves them into respective directories (C3 or T3).

polsartools.uavsar_grd(annFile, matrix='C3')

  Extracts specified matrix elements (C3 or T3) from a UAVSAR .ann file and saves them into respective directories (C3 or T3).

  ### Example:

      >>> uavsar_grd("path_to_file.ann", matrix='C3')
      This will extract the C3 matrix elements from the specified .ann file and
      save them in the 'C3' directory.

      >>> uavsar_grd("path_to_file.ann", matrix='T3')
      This will extract the T3 matrix elements and save them in the 'T3' directory.

  ### Parameters:

  annFilestr

    The path to the UAVSAR annotation file (.ann) that contains the radar data metadata.

  matrixstr, optional (default=’C3’)

    The type of matrix to extract. Can either be ‘C3’ or ‘T3’.

    - ‘C3’ will extract the C3 matrix elements.

    - ‘T3’ will extract the T3 matrix elements.

  ### Returns:

  None

    The function does not return any value. Instead, it creates a directory (C3 or T3) and populates it with the corresponding matrix elements.

  ### Raises:

  FileNotFoundError

    If the specified .ann file does not exist or cannot be found.

  ValueError

    If the matrix argument is not one of ‘C3’ or ‘T3’.

## MLC (`uavsar_mlc`)

The uavsar_mlc function extracts matrix elements (C3 or T3) from the given UAVSAR .ann file and saves them into respective directories (C3 or T3).

polsartools.uavsar_mlc(annFile, matrix='C3')

  Extracts specified matrix elements (C3 or T3) from a UAVSAR .ann file and saves them into respective directories (C3 or T3).

  ### Example:

      >>> uavsar_mlc("path_to_file.ann", matrix='C3')
      This will extract the C3 matrix elements from the specified .ann file and
      save them in the 'C3' directory.

      >>> uavsar_mlc("path_to_file.ann", matrix='T3')
      This will extract the T3 matrix elements and save them in the 'T3' directory.

  ### Parameters:

  annFilestr

    The path to the UAVSAR annotation file (.ann) that contains the radar data metadata.

  matrixstr, optional (default=’C3’)

    The type of matrix to extract. Can either be ‘C3’ or ‘T3’.

    - ‘C3’ will extract the C3 matrix elements.

    - ‘T3’ will extract the T3 matrix elements.

  ### Returns:

  None

    The function does not return any value. Instead, it creates a directory (C3 or T3) and populates it with the corresponding matrix elements.

  ### Raises:

  FileNotFoundError

    If the specified .ann file does not exist or cannot be found.

  ValueError

    If the matrix argument is not one of ‘C3’ or ‘T3’.